California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 020 - RESTRICTS PAROLE FOR NON-VIOLENT OFFENDERS. AUTHORIZES FELONY SENTENCES FOR CERTAIN OFFENSES CURRENTLY TREATED ONLY AS MISDEMEANORS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428950 | PICO CALIFORNIA ACTION FUND-YES ON 15, NO ON 20 (NONPROFIT 501 (C) (4) ) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405294 | PICO CALIFORNIA ACTION SUPPORTING SCHOOLS AND COMMUNITIES FIRST - YES ON 15, NO ON 20 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405068 | PROTECTING CALIFORNIA COOPER BALLOT MEASURE COMMITTEE, YES ON PROP. 20 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1427383 | HEISING-SIMONS ACTION FUND NONPROFIT 501 (C) (4) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1404164 | COMMITTEE FOR CALIFORNIA ISSUES PAC | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1399447 | YES ON 20 - KEEP CALIFORNIA SAFE, A PROJECT OF THE CALIFORNIA PUBLIC SAFETY PARTNERSHIP ISSUES COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1417455 | COMMITTEE FOR CALIFORNIA, NO ON PROP 20 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1421110 | NO ON PROP 20 - CALIFORNIANS AGAINST THE PRISON SPENDING SCAM | OPPOSE